# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/map/proto/map_lane.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.map.proto import map_id_pb2 as modules_dot_map_dot_proto_dot_map__id__pb2
from modules.map.proto import map_geometry_pb2 as modules_dot_map_dot_proto_dot_map__geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/map/proto/map_lane.proto',
  package='apollo.hdmap',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n modules/map/proto/map_lane.proto\x12\x0c\x61pollo.hdmap\x1a\x1emodules/map/proto/map_id.proto\x1a$modules/map/proto/map_geometry.proto\"\xcb\x01\n\x10LaneBoundaryType\x12\t\n\x01s\x18\x01 \x01(\x01\x12\x32\n\x05types\x18\x02 \x03(\x0e\x32#.apollo.hdmap.LaneBoundaryType.Type\"x\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x11\n\rDOTTED_YELLOW\x10\x01\x12\x10\n\x0c\x44OTTED_WHITE\x10\x02\x12\x10\n\x0cSOLID_YELLOW\x10\x03\x12\x0f\n\x0bSOLID_WHITE\x10\x04\x12\x11\n\rDOUBLE_YELLOW\x10\x05\x12\x08\n\x04\x43URB\x10\x06\"\x8a\x01\n\x0cLaneBoundary\x12\"\n\x05\x63urve\x18\x01 \x01(\x0b\x32\x13.apollo.hdmap.Curve\x12\x0e\n\x06length\x18\x02 \x01(\x01\x12\x0f\n\x07virtual\x18\x03 \x01(\x08\x12\x35\n\rboundary_type\x18\x04 \x03(\x0b\x32\x1e.apollo.hdmap.LaneBoundaryType\"1\n\x15LaneSampleAssociation\x12\t\n\x01s\x18\x01 \x01(\x01\x12\r\n\x05width\x18\x02 \x01(\x01\"\xee\t\n\x04Lane\x12\x1c\n\x02id\x18\x01 \x01(\x0b\x32\x10.apollo.hdmap.Id\x12*\n\rcentral_curve\x18\x02 \x01(\x0b\x32\x13.apollo.hdmap.Curve\x12\x31\n\rleft_boundary\x18\x03 \x01(\x0b\x32\x1a.apollo.hdmap.LaneBoundary\x12\x32\n\x0eright_boundary\x18\x04 \x01(\x0b\x32\x1a.apollo.hdmap.LaneBoundary\x12\x0e\n\x06length\x18\x05 \x01(\x01\x12\x13\n\x0bspeed_limit\x18\x06 \x01(\x01\x12$\n\noverlap_id\x18\x07 \x03(\x0b\x32\x10.apollo.hdmap.Id\x12(\n\x0epredecessor_id\x18\x08 \x03(\x0b\x32\x10.apollo.hdmap.Id\x12&\n\x0csuccessor_id\x18\t \x03(\x0b\x32\x10.apollo.hdmap.Id\x12\x37\n\x1dleft_neighbor_forward_lane_id\x18\n \x03(\x0b\x32\x10.apollo.hdmap.Id\x12\x38\n\x1eright_neighbor_forward_lane_id\x18\x0b \x03(\x0b\x32\x10.apollo.hdmap.Id\x12)\n\x04type\x18\x0c \x01(\x0e\x32\x1b.apollo.hdmap.Lane.LaneType\x12)\n\x04turn\x18\r \x01(\x0e\x32\x1b.apollo.hdmap.Lane.LaneTurn\x12\x37\n\x1dleft_neighbor_reverse_lane_id\x18\x0e \x03(\x0b\x32\x10.apollo.hdmap.Id\x12\x38\n\x1eright_neighbor_reverse_lane_id\x18\x0f \x03(\x0b\x32\x10.apollo.hdmap.Id\x12%\n\x0bjunction_id\x18\x10 \x01(\x0b\x32\x10.apollo.hdmap.Id\x12\x38\n\x0bleft_sample\x18\x11 \x03(\x0b\x32#.apollo.hdmap.LaneSampleAssociation\x12\x39\n\x0cright_sample\x18\x12 \x03(\x0b\x32#.apollo.hdmap.LaneSampleAssociation\x12\x33\n\tdirection\x18\x13 \x01(\x0e\x32 .apollo.hdmap.Lane.LaneDirection\x12=\n\x10left_road_sample\x18\x14 \x03(\x0b\x32#.apollo.hdmap.LaneSampleAssociation\x12>\n\x11right_road_sample\x18\x15 \x03(\x0b\x32#.apollo.hdmap.LaneSampleAssociation\x12.\n\x14self_reverse_lane_id\x18\x16 \x03(\x0b\x32\x10.apollo.hdmap.Id\"[\n\x08LaneType\x12\x08\n\x04NONE\x10\x01\x12\x10\n\x0c\x43ITY_DRIVING\x10\x02\x12\n\n\x06\x42IKING\x10\x03\x12\x0c\n\x08SIDEWALK\x10\x04\x12\x0b\n\x07PARKING\x10\x05\x12\x0c\n\x08SHOULDER\x10\x06\"B\n\x08LaneTurn\x12\x0b\n\x07NO_TURN\x10\x01\x12\r\n\tLEFT_TURN\x10\x02\x12\x0e\n\nRIGHT_TURN\x10\x03\x12\n\n\x06U_TURN\x10\x04\";\n\rLaneDirection\x12\x0b\n\x07\x46ORWARD\x10\x01\x12\x0c\n\x08\x42\x41\x43KWARD\x10\x02\x12\x0f\n\x0b\x42IDIRECTION\x10\x03'
  ,
  dependencies=[modules_dot_map_dot_proto_dot_map__id__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__geometry__pb2.DESCRIPTOR,])



_LANEBOUNDARYTYPE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.hdmap.LaneBoundaryType.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOTTED_YELLOW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOTTED_WHITE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOLID_YELLOW', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOLID_WHITE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE_YELLOW', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CURB', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=204,
  serialized_end=324,
)
_sym_db.RegisterEnumDescriptor(_LANEBOUNDARYTYPE_TYPE)

_LANE_LANETYPE = _descriptor.EnumDescriptor(
  name='LaneType',
  full_name='apollo.hdmap.Lane.LaneType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CITY_DRIVING', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BIKING', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIDEWALK', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHOULDER', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1561,
  serialized_end=1652,
)
_sym_db.RegisterEnumDescriptor(_LANE_LANETYPE)

_LANE_LANETURN = _descriptor.EnumDescriptor(
  name='LaneTurn',
  full_name='apollo.hdmap.Lane.LaneTurn',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_TURN', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_TURN', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_TURN', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='U_TURN', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1654,
  serialized_end=1720,
)
_sym_db.RegisterEnumDescriptor(_LANE_LANETURN)

_LANE_LANEDIRECTION = _descriptor.EnumDescriptor(
  name='LaneDirection',
  full_name='apollo.hdmap.Lane.LaneDirection',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FORWARD', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BACKWARD', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BIDIRECTION', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1722,
  serialized_end=1781,
)
_sym_db.RegisterEnumDescriptor(_LANE_LANEDIRECTION)


_LANEBOUNDARYTYPE = _descriptor.Descriptor(
  name='LaneBoundaryType',
  full_name='apollo.hdmap.LaneBoundaryType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='s', full_name='apollo.hdmap.LaneBoundaryType.s', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='types', full_name='apollo.hdmap.LaneBoundaryType.types', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LANEBOUNDARYTYPE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=324,
)


_LANEBOUNDARY = _descriptor.Descriptor(
  name='LaneBoundary',
  full_name='apollo.hdmap.LaneBoundary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='curve', full_name='apollo.hdmap.LaneBoundary.curve', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='apollo.hdmap.LaneBoundary.length', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual', full_name='apollo.hdmap.LaneBoundary.virtual', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boundary_type', full_name='apollo.hdmap.LaneBoundary.boundary_type', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=327,
  serialized_end=465,
)


_LANESAMPLEASSOCIATION = _descriptor.Descriptor(
  name='LaneSampleAssociation',
  full_name='apollo.hdmap.LaneSampleAssociation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='s', full_name='apollo.hdmap.LaneSampleAssociation.s', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='apollo.hdmap.LaneSampleAssociation.width', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=467,
  serialized_end=516,
)


_LANE = _descriptor.Descriptor(
  name='Lane',
  full_name='apollo.hdmap.Lane',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.hdmap.Lane.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='central_curve', full_name='apollo.hdmap.Lane.central_curve', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_boundary', full_name='apollo.hdmap.Lane.left_boundary', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_boundary', full_name='apollo.hdmap.Lane.right_boundary', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='apollo.hdmap.Lane.length', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_limit', full_name='apollo.hdmap.Lane.speed_limit', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overlap_id', full_name='apollo.hdmap.Lane.overlap_id', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='predecessor_id', full_name='apollo.hdmap.Lane.predecessor_id', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='successor_id', full_name='apollo.hdmap.Lane.successor_id', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_neighbor_forward_lane_id', full_name='apollo.hdmap.Lane.left_neighbor_forward_lane_id', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_neighbor_forward_lane_id', full_name='apollo.hdmap.Lane.right_neighbor_forward_lane_id', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.hdmap.Lane.type', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turn', full_name='apollo.hdmap.Lane.turn', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_neighbor_reverse_lane_id', full_name='apollo.hdmap.Lane.left_neighbor_reverse_lane_id', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_neighbor_reverse_lane_id', full_name='apollo.hdmap.Lane.right_neighbor_reverse_lane_id', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_id', full_name='apollo.hdmap.Lane.junction_id', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_sample', full_name='apollo.hdmap.Lane.left_sample', index=16,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_sample', full_name='apollo.hdmap.Lane.right_sample', index=17,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='apollo.hdmap.Lane.direction', index=18,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_road_sample', full_name='apollo.hdmap.Lane.left_road_sample', index=19,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_road_sample', full_name='apollo.hdmap.Lane.right_road_sample', index=20,
      number=21, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='self_reverse_lane_id', full_name='apollo.hdmap.Lane.self_reverse_lane_id', index=21,
      number=22, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LANE_LANETYPE,
    _LANE_LANETURN,
    _LANE_LANEDIRECTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=1781,
)

_LANEBOUNDARYTYPE.fields_by_name['types'].enum_type = _LANEBOUNDARYTYPE_TYPE
_LANEBOUNDARYTYPE_TYPE.containing_type = _LANEBOUNDARYTYPE
_LANEBOUNDARY.fields_by_name['curve'].message_type = modules_dot_map_dot_proto_dot_map__geometry__pb2._CURVE
_LANEBOUNDARY.fields_by_name['boundary_type'].message_type = _LANEBOUNDARYTYPE
_LANE.fields_by_name['id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_LANE.fields_by_name['central_curve'].message_type = modules_dot_map_dot_proto_dot_map__geometry__pb2._CURVE
_LANE.fields_by_name['left_boundary'].message_type = _LANEBOUNDARY
_LANE.fields_by_name['right_boundary'].message_type = _LANEBOUNDARY
_LANE.fields_by_name['overlap_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_LANE.fields_by_name['predecessor_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_LANE.fields_by_name['successor_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_LANE.fields_by_name['left_neighbor_forward_lane_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_LANE.fields_by_name['right_neighbor_forward_lane_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_LANE.fields_by_name['type'].enum_type = _LANE_LANETYPE
_LANE.fields_by_name['turn'].enum_type = _LANE_LANETURN
_LANE.fields_by_name['left_neighbor_reverse_lane_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_LANE.fields_by_name['right_neighbor_reverse_lane_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_LANE.fields_by_name['junction_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_LANE.fields_by_name['left_sample'].message_type = _LANESAMPLEASSOCIATION
_LANE.fields_by_name['right_sample'].message_type = _LANESAMPLEASSOCIATION
_LANE.fields_by_name['direction'].enum_type = _LANE_LANEDIRECTION
_LANE.fields_by_name['left_road_sample'].message_type = _LANESAMPLEASSOCIATION
_LANE.fields_by_name['right_road_sample'].message_type = _LANESAMPLEASSOCIATION
_LANE.fields_by_name['self_reverse_lane_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_LANE_LANETYPE.containing_type = _LANE
_LANE_LANETURN.containing_type = _LANE
_LANE_LANEDIRECTION.containing_type = _LANE
DESCRIPTOR.message_types_by_name['LaneBoundaryType'] = _LANEBOUNDARYTYPE
DESCRIPTOR.message_types_by_name['LaneBoundary'] = _LANEBOUNDARY
DESCRIPTOR.message_types_by_name['LaneSampleAssociation'] = _LANESAMPLEASSOCIATION
DESCRIPTOR.message_types_by_name['Lane'] = _LANE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LaneBoundaryType = _reflection.GeneratedProtocolMessageType('LaneBoundaryType', (_message.Message,), {
  'DESCRIPTOR' : _LANEBOUNDARYTYPE,
  '__module__' : 'modules.map.proto.map_lane_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.LaneBoundaryType)
  })
_sym_db.RegisterMessage(LaneBoundaryType)

LaneBoundary = _reflection.GeneratedProtocolMessageType('LaneBoundary', (_message.Message,), {
  'DESCRIPTOR' : _LANEBOUNDARY,
  '__module__' : 'modules.map.proto.map_lane_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.LaneBoundary)
  })
_sym_db.RegisterMessage(LaneBoundary)

LaneSampleAssociation = _reflection.GeneratedProtocolMessageType('LaneSampleAssociation', (_message.Message,), {
  'DESCRIPTOR' : _LANESAMPLEASSOCIATION,
  '__module__' : 'modules.map.proto.map_lane_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.LaneSampleAssociation)
  })
_sym_db.RegisterMessage(LaneSampleAssociation)

Lane = _reflection.GeneratedProtocolMessageType('Lane', (_message.Message,), {
  'DESCRIPTOR' : _LANE,
  '__module__' : 'modules.map.proto.map_lane_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.Lane)
  })
_sym_db.RegisterMessage(Lane)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/gnss/proto/gnss_raw_observation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/gnss/proto/gnss_raw_observation.proto',
  package='apollo.drivers.gnss',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5modules/drivers/gnss/proto/gnss_raw_observation.proto\x12\x13\x61pollo.drivers.gnss\"\x92\x02\n\x0f\x42\x61ndObservation\x12>\n\x07\x62\x61nd_id\x18\x01 \x01(\x0e\x32\x1f.apollo.drivers.gnss.GnssBandID:\x0c\x42\x41ND_UNKNOWN\x12\x17\n\x0f\x66requency_value\x18\x02 \x01(\x01\x12\x42\n\x0bpseudo_type\x18\x03 \x01(\x0e\x32\x1f.apollo.drivers.gnss.PseudoType:\x0c\x43ODE_UNKNOWN\x12\x14\n\x0cpseudo_range\x18\x04 \x01(\x01\x12\x15\n\rcarrier_phase\x18\x05 \x01(\x01\x12\x17\n\x0floss_lock_index\x18\x06 \x01(\r\x12\x0f\n\x07\x64oppler\x18\x07 \x01(\x01\x12\x0b\n\x03snr\x18\x08 \x01(\x02\"\xae\x01\n\x14SatelliteObservation\x12\x0f\n\x07sat_prn\x18\x01 \x01(\r\x12\x37\n\x07sat_sys\x18\x02 \x01(\x0e\x32\x1d.apollo.drivers.gnss.GnssType:\x07GPS_SYS\x12\x14\n\x0c\x62\x61nd_obs_num\x18\x03 \x01(\r\x12\x36\n\x08\x62\x61nd_obs\x18\x04 \x03(\x0b\x32$.apollo.drivers.gnss.BandObservation\"\xbb\x02\n\x10\x45pochObservation\x12\x13\n\x0breceiver_id\x18\x01 \x01(\r\x12\x43\n\x0egnss_time_type\x18\x02 \x01(\x0e\x32!.apollo.drivers.gnss.GnssTimeType:\x08GPS_TIME\x12\x11\n\tgnss_week\x18\x03 \x01(\r\x12\x15\n\rgnss_second_s\x18\x04 \x01(\x01\x12\x12\n\nposition_x\x18\x05 \x01(\x01\x12\x12\n\nposition_y\x18\x06 \x01(\x01\x12\x12\n\nposition_z\x18\x07 \x01(\x01\x12\x16\n\x0bhealth_flag\x18\x08 \x01(\r:\x01\x30\x12\x13\n\x0bsat_obs_num\x18\t \x01(\r\x12:\n\x07sat_obs\x18\n \x03(\x0b\x32).apollo.drivers.gnss.SatelliteObservation\"\xa7\x05\n\x0cKepplerOrbit\x12\x39\n\tgnss_type\x18\x01 \x01(\x0e\x32\x1d.apollo.drivers.gnss.GnssType:\x07GPS_SYS\x12\x0f\n\x07sat_prn\x18\x02 \x01(\r\x12\x43\n\x0egnss_time_type\x18\x03 \x01(\x0e\x32!.apollo.drivers.gnss.GnssTimeType:\x08GPS_TIME\x12\x0c\n\x04year\x18\x04 \x01(\r\x12\r\n\x05month\x18\x05 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x06 \x01(\r\x12\x0c\n\x04hour\x18\x07 \x01(\r\x12\x0e\n\x06minute\x18\x08 \x01(\r\x12\x10\n\x08second_s\x18\t \x01(\x01\x12\x10\n\x08week_num\x18\n \x01(\r\x12\x10\n\x08reserved\x18\x0b \x01(\x01\x12\x0b\n\x03\x61\x66\x30\x18\x0c \x01(\x01\x12\x0b\n\x03\x61\x66\x31\x18\r \x01(\x01\x12\x0b\n\x03\x61\x66\x32\x18\x0e \x01(\x01\x12\x0c\n\x04iode\x18\x0f \x01(\x01\x12\x0e\n\x06\x64\x65ltan\x18\x10 \x01(\x01\x12\n\n\x02m0\x18\x11 \x01(\x01\x12\t\n\x01\x65\x18\x12 \x01(\x01\x12\r\n\x05roota\x18\x13 \x01(\x01\x12\x0b\n\x03toe\x18\x14 \x01(\x01\x12\x0b\n\x03toc\x18\x15 \x01(\x01\x12\x0b\n\x03\x63ic\x18\x16 \x01(\x01\x12\x0b\n\x03\x63rc\x18\x17 \x01(\x01\x12\x0b\n\x03\x63is\x18\x18 \x01(\x01\x12\x0b\n\x03\x63rs\x18\x19 \x01(\x01\x12\x0b\n\x03\x63uc\x18\x1a \x01(\x01\x12\x0b\n\x03\x63us\x18\x1b \x01(\x01\x12\x0e\n\x06omega0\x18\x1c \x01(\x01\x12\r\n\x05omega\x18\x1d \x01(\x01\x12\n\n\x02i0\x18\x1e \x01(\x01\x12\x10\n\x08omegadot\x18\x1f \x01(\x01\x12\x0c\n\x04idot\x18  \x01(\x01\x12\x18\n\x10\x63odesonL2channel\x18! \x01(\x01\x12\x13\n\x0bL2Pdataflag\x18\" \x01(\r\x12\x10\n\x08\x61\x63\x63uracy\x18# \x01(\r\x12\x0e\n\x06health\x18$ \x01(\r\x12\x0b\n\x03tgd\x18% \x01(\x01\x12\x0c\n\x04iodc\x18& \x01(\x01\"\xeb\x04\n\x0cGlonassOrbit\x12\x39\n\tgnss_type\x18\x01 \x01(\x0e\x32\x1d.apollo.drivers.gnss.GnssType:\x07GLO_SYS\x12\x10\n\x08slot_prn\x18\x02 \x01(\r\x12\x43\n\x0egnss_time_type\x18\x03 \x01(\x0e\x32!.apollo.drivers.gnss.GnssTimeType:\x08GLO_TIME\x12\x0b\n\x03toe\x18\x04 \x01(\x01\x12\x0c\n\x04year\x18\x05 \x01(\r\x12\r\n\x05month\x18\x06 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x07 \x01(\r\x12\x0c\n\x04hour\x18\x08 \x01(\r\x12\x0e\n\x06minute\x18\t \x01(\r\x12\x10\n\x08second_s\x18\n \x01(\x01\x12\x14\n\x0c\x66requency_no\x18\x0b \x01(\x05\x12\x10\n\x08week_num\x18\x0c \x01(\r\x12\x15\n\rweek_second_s\x18\r \x01(\x01\x12\n\n\x02tk\x18\x0e \x01(\x01\x12\x14\n\x0c\x63lock_offset\x18\x0f \x01(\x01\x12\x13\n\x0b\x63lock_drift\x18\x10 \x01(\x01\x12\x0e\n\x06health\x18\x11 \x01(\r\x12\x12\n\nposition_x\x18\x12 \x01(\x01\x12\x12\n\nposition_y\x18\x13 \x01(\x01\x12\x12\n\nposition_z\x18\x14 \x01(\x01\x12\x12\n\nvelocity_x\x18\x15 \x01(\x01\x12\x12\n\nvelocity_y\x18\x16 \x01(\x01\x12\x12\n\nvelocity_z\x18\x17 \x01(\x01\x12\x14\n\x0c\x61\x63\x63\x65lerate_x\x18\x18 \x01(\x01\x12\x14\n\x0c\x61\x63\x63\x65lerate_y\x18\x19 \x01(\x01\x12\x14\n\x0c\x61\x63\x63\x65lerate_z\x18\x1a \x01(\x01\x12\x11\n\tinfor_age\x18\x1b \x01(\x01\x12\x0f\n\x07sat_prn\x18\x1c \x01(\r\"\xbe\x01\n\rGnssEphemeris\x12\x39\n\tgnss_type\x18\x01 \x01(\x0e\x32\x1d.apollo.drivers.gnss.GnssType:\x07GLO_SYS\x12\x38\n\rkeppler_orbit\x18\x02 \x01(\x0b\x32!.apollo.drivers.gnss.KepplerOrbit\x12\x38\n\rglonass_orbit\x18\x03 \x01(\x0b\x32!.apollo.drivers.gnss.GlonassOrbit*\x8a\x01\n\nGnssBandID\x12\x10\n\x0c\x42\x41ND_UNKNOWN\x10\x00\x12\n\n\x06GPS_L1\x10\x01\x12\n\n\x06GPS_L2\x10\x02\x12\n\n\x06GPS_L5\x10\x03\x12\n\n\x06\x42\x44S_B1\x10\x04\x12\n\n\x06\x42\x44S_B2\x10\x05\x12\n\n\x06\x42\x44S_B3\x10\x06\x12\n\n\x06GLO_G1\x10\x07\x12\n\n\x06GLO_G2\x10\x08\x12\n\n\x06GLO_G3\x10\t*X\n\x0cGnssTimeType\x12\x10\n\x0cTIME_UNKNOWN\x10\x00\x12\x0c\n\x08GPS_TIME\x10\x01\x12\x0c\n\x08\x42\x44S_TIME\x10\x02\x12\x0c\n\x08GLO_TIME\x10\x03\x12\x0c\n\x08GAL_TIME\x10\x04*O\n\x08GnssType\x12\x0f\n\x0bSYS_UNKNOWN\x10\x00\x12\x0b\n\x07GPS_SYS\x10\x01\x12\x0b\n\x07\x42\x44S_SYS\x10\x02\x12\x0b\n\x07GLO_SYS\x10\x03\x12\x0b\n\x07GAL_SYS\x10\x04*B\n\nPseudoType\x12\x10\n\x0c\x43ODE_UNKNOWN\x10\x00\x12\x0e\n\nCORSE_CODE\x10\x01\x12\x12\n\x0ePRECISION_CODE\x10\x02'
)

_GNSSBANDID = _descriptor.EnumDescriptor(
  name='GnssBandID',
  full_name='apollo.drivers.gnss.GnssBandID',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BAND_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GPS_L1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GPS_L2', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GPS_L5', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BDS_B1', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BDS_B2', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BDS_B3', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GLO_G1', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GLO_G2', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GLO_G3', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2348,
  serialized_end=2486,
)
_sym_db.RegisterEnumDescriptor(_GNSSBANDID)

GnssBandID = enum_type_wrapper.EnumTypeWrapper(_GNSSBANDID)
_GNSSTIMETYPE = _descriptor.EnumDescriptor(
  name='GnssTimeType',
  full_name='apollo.drivers.gnss.GnssTimeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TIME_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GPS_TIME', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BDS_TIME', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GLO_TIME', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAL_TIME', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2488,
  serialized_end=2576,
)
_sym_db.RegisterEnumDescriptor(_GNSSTIMETYPE)

GnssTimeType = enum_type_wrapper.EnumTypeWrapper(_GNSSTIMETYPE)
_GNSSTYPE = _descriptor.EnumDescriptor(
  name='GnssType',
  full_name='apollo.drivers.gnss.GnssType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SYS_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GPS_SYS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BDS_SYS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GLO_SYS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAL_SYS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2578,
  serialized_end=2657,
)
_sym_db.RegisterEnumDescriptor(_GNSSTYPE)

GnssType = enum_type_wrapper.EnumTypeWrapper(_GNSSTYPE)
_PSEUDOTYPE = _descriptor.EnumDescriptor(
  name='PseudoType',
  full_name='apollo.drivers.gnss.PseudoType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CODE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CORSE_CODE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRECISION_CODE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2659,
  serialized_end=2725,
)
_sym_db.RegisterEnumDescriptor(_PSEUDOTYPE)

PseudoType = enum_type_wrapper.EnumTypeWrapper(_PSEUDOTYPE)
BAND_UNKNOWN = 0
GPS_L1 = 1
GPS_L2 = 2
GPS_L5 = 3
BDS_B1 = 4
BDS_B2 = 5
BDS_B3 = 6
GLO_G1 = 7
GLO_G2 = 8
GLO_G3 = 9
TIME_UNKNOWN = 0
GPS_TIME = 1
BDS_TIME = 2
GLO_TIME = 3
GAL_TIME = 4
SYS_UNKNOWN = 0
GPS_SYS = 1
BDS_SYS = 2
GLO_SYS = 3
GAL_SYS = 4
CODE_UNKNOWN = 0
CORSE_CODE = 1
PRECISION_CODE = 2



_BANDOBSERVATION = _descriptor.Descriptor(
  name='BandObservation',
  full_name='apollo.drivers.gnss.BandObservation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='band_id', full_name='apollo.drivers.gnss.BandObservation.band_id', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frequency_value', full_name='apollo.drivers.gnss.BandObservation.frequency_value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pseudo_type', full_name='apollo.drivers.gnss.BandObservation.pseudo_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pseudo_range', full_name='apollo.drivers.gnss.BandObservation.pseudo_range', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='carrier_phase', full_name='apollo.drivers.gnss.BandObservation.carrier_phase', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loss_lock_index', full_name='apollo.drivers.gnss.BandObservation.loss_lock_index', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doppler', full_name='apollo.drivers.gnss.BandObservation.doppler', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snr', full_name='apollo.drivers.gnss.BandObservation.snr', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=353,
)


_SATELLITEOBSERVATION = _descriptor.Descriptor(
  name='SatelliteObservation',
  full_name='apollo.drivers.gnss.SatelliteObservation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sat_prn', full_name='apollo.drivers.gnss.SatelliteObservation.sat_prn', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sat_sys', full_name='apollo.drivers.gnss.SatelliteObservation.sat_sys', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='band_obs_num', full_name='apollo.drivers.gnss.SatelliteObservation.band_obs_num', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='band_obs', full_name='apollo.drivers.gnss.SatelliteObservation.band_obs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=356,
  serialized_end=530,
)


_EPOCHOBSERVATION = _descriptor.Descriptor(
  name='EpochObservation',
  full_name='apollo.drivers.gnss.EpochObservation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='receiver_id', full_name='apollo.drivers.gnss.EpochObservation.receiver_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gnss_time_type', full_name='apollo.drivers.gnss.EpochObservation.gnss_time_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gnss_week', full_name='apollo.drivers.gnss.EpochObservation.gnss_week', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gnss_second_s', full_name='apollo.drivers.gnss.EpochObservation.gnss_second_s', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_x', full_name='apollo.drivers.gnss.EpochObservation.position_x', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_y', full_name='apollo.drivers.gnss.EpochObservation.position_y', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_z', full_name='apollo.drivers.gnss.EpochObservation.position_z', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health_flag', full_name='apollo.drivers.gnss.EpochObservation.health_flag', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sat_obs_num', full_name='apollo.drivers.gnss.EpochObservation.sat_obs_num', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sat_obs', full_name='apollo.drivers.gnss.EpochObservation.sat_obs', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=533,
  serialized_end=848,
)


_KEPPLERORBIT = _descriptor.Descriptor(
  name='KepplerOrbit',
  full_name='apollo.drivers.gnss.KepplerOrbit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gnss_type', full_name='apollo.drivers.gnss.KepplerOrbit.gnss_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sat_prn', full_name='apollo.drivers.gnss.KepplerOrbit.sat_prn', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gnss_time_type', full_name='apollo.drivers.gnss.KepplerOrbit.gnss_time_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='year', full_name='apollo.drivers.gnss.KepplerOrbit.year', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='apollo.drivers.gnss.KepplerOrbit.month', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='day', full_name='apollo.drivers.gnss.KepplerOrbit.day', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hour', full_name='apollo.drivers.gnss.KepplerOrbit.hour', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minute', full_name='apollo.drivers.gnss.KepplerOrbit.minute', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='second_s', full_name='apollo.drivers.gnss.KepplerOrbit.second_s', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='week_num', full_name='apollo.drivers.gnss.KepplerOrbit.week_num', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved', full_name='apollo.drivers.gnss.KepplerOrbit.reserved', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='af0', full_name='apollo.drivers.gnss.KepplerOrbit.af0', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='af1', full_name='apollo.drivers.gnss.KepplerOrbit.af1', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='af2', full_name='apollo.drivers.gnss.KepplerOrbit.af2', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iode', full_name='apollo.drivers.gnss.KepplerOrbit.iode', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deltan', full_name='apollo.drivers.gnss.KepplerOrbit.deltan', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m0', full_name='apollo.drivers.gnss.KepplerOrbit.m0', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='e', full_name='apollo.drivers.gnss.KepplerOrbit.e', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roota', full_name='apollo.drivers.gnss.KepplerOrbit.roota', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='toe', full_name='apollo.drivers.gnss.KepplerOrbit.toe', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='toc', full_name='apollo.drivers.gnss.KepplerOrbit.toc', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cic', full_name='apollo.drivers.gnss.KepplerOrbit.cic', index=21,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crc', full_name='apollo.drivers.gnss.KepplerOrbit.crc', index=22,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cis', full_name='apollo.drivers.gnss.KepplerOrbit.cis', index=23,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crs', full_name='apollo.drivers.gnss.KepplerOrbit.crs', index=24,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cuc', full_name='apollo.drivers.gnss.KepplerOrbit.cuc', index=25,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cus', full_name='apollo.drivers.gnss.KepplerOrbit.cus', index=26,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='omega0', full_name='apollo.drivers.gnss.KepplerOrbit.omega0', index=27,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='omega', full_name='apollo.drivers.gnss.KepplerOrbit.omega', index=28,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='i0', full_name='apollo.drivers.gnss.KepplerOrbit.i0', index=29,
      number=30, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='omegadot', full_name='apollo.drivers.gnss.KepplerOrbit.omegadot', index=30,
      number=31, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idot', full_name='apollo.drivers.gnss.KepplerOrbit.idot', index=31,
      number=32, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codesonL2channel', full_name='apollo.drivers.gnss.KepplerOrbit.codesonL2channel', index=32,
      number=33, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='L2Pdataflag', full_name='apollo.drivers.gnss.KepplerOrbit.L2Pdataflag', index=33,
      number=34, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accuracy', full_name='apollo.drivers.gnss.KepplerOrbit.accuracy', index=34,
      number=35, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health', full_name='apollo.drivers.gnss.KepplerOrbit.health', index=35,
      number=36, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tgd', full_name='apollo.drivers.gnss.KepplerOrbit.tgd', index=36,
      number=37, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iodc', full_name='apollo.drivers.gnss.KepplerOrbit.iodc', index=37,
      number=38, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=851,
  serialized_end=1530,
)


_GLONASSORBIT = _descriptor.Descriptor(
  name='GlonassOrbit',
  full_name='apollo.drivers.gnss.GlonassOrbit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gnss_type', full_name='apollo.drivers.gnss.GlonassOrbit.gnss_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slot_prn', full_name='apollo.drivers.gnss.GlonassOrbit.slot_prn', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gnss_time_type', full_name='apollo.drivers.gnss.GlonassOrbit.gnss_time_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='toe', full_name='apollo.drivers.gnss.GlonassOrbit.toe', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='year', full_name='apollo.drivers.gnss.GlonassOrbit.year', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='apollo.drivers.gnss.GlonassOrbit.month', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='day', full_name='apollo.drivers.gnss.GlonassOrbit.day', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hour', full_name='apollo.drivers.gnss.GlonassOrbit.hour', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minute', full_name='apollo.drivers.gnss.GlonassOrbit.minute', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='second_s', full_name='apollo.drivers.gnss.GlonassOrbit.second_s', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frequency_no', full_name='apollo.drivers.gnss.GlonassOrbit.frequency_no', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='week_num', full_name='apollo.drivers.gnss.GlonassOrbit.week_num', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='week_second_s', full_name='apollo.drivers.gnss.GlonassOrbit.week_second_s', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tk', full_name='apollo.drivers.gnss.GlonassOrbit.tk', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock_offset', full_name='apollo.drivers.gnss.GlonassOrbit.clock_offset', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock_drift', full_name='apollo.drivers.gnss.GlonassOrbit.clock_drift', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health', full_name='apollo.drivers.gnss.GlonassOrbit.health', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_x', full_name='apollo.drivers.gnss.GlonassOrbit.position_x', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_y', full_name='apollo.drivers.gnss.GlonassOrbit.position_y', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_z', full_name='apollo.drivers.gnss.GlonassOrbit.position_z', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity_x', full_name='apollo.drivers.gnss.GlonassOrbit.velocity_x', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity_y', full_name='apollo.drivers.gnss.GlonassOrbit.velocity_y', index=21,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity_z', full_name='apollo.drivers.gnss.GlonassOrbit.velocity_z', index=22,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accelerate_x', full_name='apollo.drivers.gnss.GlonassOrbit.accelerate_x', index=23,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accelerate_y', full_name='apollo.drivers.gnss.GlonassOrbit.accelerate_y', index=24,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accelerate_z', full_name='apollo.drivers.gnss.GlonassOrbit.accelerate_z', index=25,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='infor_age', full_name='apollo.drivers.gnss.GlonassOrbit.infor_age', index=26,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sat_prn', full_name='apollo.drivers.gnss.GlonassOrbit.sat_prn', index=27,
      number=28, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1533,
  serialized_end=2152,
)


_GNSSEPHEMERIS = _descriptor.Descriptor(
  name='GnssEphemeris',
  full_name='apollo.drivers.gnss.GnssEphemeris',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gnss_type', full_name='apollo.drivers.gnss.GnssEphemeris.gnss_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keppler_orbit', full_name='apollo.drivers.gnss.GnssEphemeris.keppler_orbit', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='glonass_orbit', full_name='apollo.drivers.gnss.GnssEphemeris.glonass_orbit', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2155,
  serialized_end=2345,
)

_BANDOBSERVATION.fields_by_name['band_id'].enum_type = _GNSSBANDID
_BANDOBSERVATION.fields_by_name['pseudo_type'].enum_type = _PSEUDOTYPE
_SATELLITEOBSERVATION.fields_by_name['sat_sys'].enum_type = _GNSSTYPE
_SATELLITEOBSERVATION.fields_by_name['band_obs'].message_type = _BANDOBSERVATION
_EPOCHOBSERVATION.fields_by_name['gnss_time_type'].enum_type = _GNSSTIMETYPE
_EPOCHOBSERVATION.fields_by_name['sat_obs'].message_type = _SATELLITEOBSERVATION
_KEPPLERORBIT.fields_by_name['gnss_type'].enum_type = _GNSSTYPE
_KEPPLERORBIT.fields_by_name['gnss_time_type'].enum_type = _GNSSTIMETYPE
_GLONASSORBIT.fields_by_name['gnss_type'].enum_type = _GNSSTYPE
_GLONASSORBIT.fields_by_name['gnss_time_type'].enum_type = _GNSSTIMETYPE
_GNSSEPHEMERIS.fields_by_name['gnss_type'].enum_type = _GNSSTYPE
_GNSSEPHEMERIS.fields_by_name['keppler_orbit'].message_type = _KEPPLERORBIT
_GNSSEPHEMERIS.fields_by_name['glonass_orbit'].message_type = _GLONASSORBIT
DESCRIPTOR.message_types_by_name['BandObservation'] = _BANDOBSERVATION
DESCRIPTOR.message_types_by_name['SatelliteObservation'] = _SATELLITEOBSERVATION
DESCRIPTOR.message_types_by_name['EpochObservation'] = _EPOCHOBSERVATION
DESCRIPTOR.message_types_by_name['KepplerOrbit'] = _KEPPLERORBIT
DESCRIPTOR.message_types_by_name['GlonassOrbit'] = _GLONASSORBIT
DESCRIPTOR.message_types_by_name['GnssEphemeris'] = _GNSSEPHEMERIS
DESCRIPTOR.enum_types_by_name['GnssBandID'] = _GNSSBANDID
DESCRIPTOR.enum_types_by_name['GnssTimeType'] = _GNSSTIMETYPE
DESCRIPTOR.enum_types_by_name['GnssType'] = _GNSSTYPE
DESCRIPTOR.enum_types_by_name['PseudoType'] = _PSEUDOTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BandObservation = _reflection.GeneratedProtocolMessageType('BandObservation', (_message.Message,), {
  'DESCRIPTOR' : _BANDOBSERVATION,
  '__module__' : 'modules.drivers.gnss.proto.gnss_raw_observation_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.BandObservation)
  })
_sym_db.RegisterMessage(BandObservation)

SatelliteObservation = _reflection.GeneratedProtocolMessageType('SatelliteObservation', (_message.Message,), {
  'DESCRIPTOR' : _SATELLITEOBSERVATION,
  '__module__' : 'modules.drivers.gnss.proto.gnss_raw_observation_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.SatelliteObservation)
  })
_sym_db.RegisterMessage(SatelliteObservation)

EpochObservation = _reflection.GeneratedProtocolMessageType('EpochObservation', (_message.Message,), {
  'DESCRIPTOR' : _EPOCHOBSERVATION,
  '__module__' : 'modules.drivers.gnss.proto.gnss_raw_observation_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.EpochObservation)
  })
_sym_db.RegisterMessage(EpochObservation)

KepplerOrbit = _reflection.GeneratedProtocolMessageType('KepplerOrbit', (_message.Message,), {
  'DESCRIPTOR' : _KEPPLERORBIT,
  '__module__' : 'modules.drivers.gnss.proto.gnss_raw_observation_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.KepplerOrbit)
  })
_sym_db.RegisterMessage(KepplerOrbit)

GlonassOrbit = _reflection.GeneratedProtocolMessageType('GlonassOrbit', (_message.Message,), {
  'DESCRIPTOR' : _GLONASSORBIT,
  '__module__' : 'modules.drivers.gnss.proto.gnss_raw_observation_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.GlonassOrbit)
  })
_sym_db.RegisterMessage(GlonassOrbit)

GnssEphemeris = _reflection.GeneratedProtocolMessageType('GnssEphemeris', (_message.Message,), {
  'DESCRIPTOR' : _GNSSEPHEMERIS,
  '__module__' : 'modules.drivers.gnss.proto.gnss_raw_observation_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.GnssEphemeris)
  })
_sym_db.RegisterMessage(GnssEphemeris)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/camera/proto/config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/camera/proto/config.proto',
  package='apollo.drivers.camera.config',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)modules/drivers/camera/proto/config.proto\x12\x1c\x61pollo.drivers.camera.config\"\xd3\x06\n\x06\x43onfig\x12\x12\n\ncamera_dev\x18\x01 \x01(\t\x12\x10\n\x08\x66rame_id\x18\x02 \x01(\t\x12\x1a\n\x0cpixel_format\x18\x03 \x01(\t:\x04yuyv\x12\x39\n\tio_method\x18\x04 \x01(\x0e\x32&.apollo.drivers.camera.config.IOMethod\x12\r\n\x05width\x18\x05 \x01(\r\x12\x0e\n\x06height\x18\x06 \x01(\r\x12\x12\n\nframe_rate\x18\x07 \x01(\r\x12\x19\n\nmonochrome\x18\x08 \x01(\x08:\x05\x66\x61lse\x12\x16\n\nbrightness\x18\t \x01(\x05:\x02-1\x12\x14\n\x08\x63ontrast\x18\n \x01(\x05:\x02-1\x12\x16\n\nsaturation\x18\x0b \x01(\x05:\x02-1\x12\x15\n\tsharpness\x18\x0c \x01(\x05:\x02-1\x12\x10\n\x04gain\x18\r \x01(\x05:\x02-1\x12\x19\n\nauto_focus\x18\x0e \x01(\x08:\x05\x66\x61lse\x12\x11\n\x05\x66ocus\x18\x0f \x01(\x05:\x02-1\x12\x1b\n\rauto_exposure\x18\x10 \x01(\x08:\x04true\x12\x15\n\x08\x65xposure\x18\x11 \x01(\x05:\x03\x31\x30\x30\x12 \n\x12\x61uto_white_balance\x18\x12 \x01(\x08:\x04true\x12\x1b\n\rwhite_balance\x18\x13 \x01(\x05:\x04\x34\x30\x30\x30\x12\x1a\n\x0f\x62ytes_per_pixel\x18\x14 \x01(\r:\x01\x33\x12\x1b\n\x10trigger_internal\x18\x15 \x01(\r:\x01\x30\x12\x17\n\x0btrigger_fps\x18\x16 \x01(\r:\x02\x33\x30\x12\x14\n\x0c\x63hannel_name\x18\x17 \x01(\t\x12\x1c\n\x0e\x64\x65vice_wait_ms\x18\x18 \x01(\r:\x04\x32\x30\x30\x30\x12\x16\n\tspin_rate\x18\x19 \x01(\r:\x03\x32\x30\x30\x12=\n\x0boutput_type\x18\x1a \x01(\x0e\x32(.apollo.drivers.camera.config.OutputType\x12J\n\rcompress_conf\x18\x1b \x01(\x0b\x32\x33.apollo.drivers.camera.config.Config.CompressConfig\x1a\x45\n\x0e\x43ompressConfig\x12\x16\n\x0eoutput_channel\x18\x01 \x01(\t\x12\x1b\n\x0fimage_pool_size\x18\x02 \x01(\r:\x02\x32\x30*`\n\x08IOMethod\x12\x15\n\x11IO_METHOD_UNKNOWN\x10\x00\x12\x12\n\x0eIO_METHOD_READ\x10\x01\x12\x12\n\x0eIO_METHOD_MMAP\x10\x02\x12\x15\n\x11IO_METHOD_USERPTR\x10\x03*\x1f\n\nOutputType\x12\x08\n\x04YUYV\x10\x00\x12\x07\n\x03RGB\x10\x01'
)

_IOMETHOD = _descriptor.EnumDescriptor(
  name='IOMethod',
  full_name='apollo.drivers.camera.config.IOMethod',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IO_METHOD_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IO_METHOD_READ', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IO_METHOD_MMAP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IO_METHOD_USERPTR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=929,
  serialized_end=1025,
)
_sym_db.RegisterEnumDescriptor(_IOMETHOD)

IOMethod = enum_type_wrapper.EnumTypeWrapper(_IOMETHOD)
_OUTPUTTYPE = _descriptor.EnumDescriptor(
  name='OutputType',
  full_name='apollo.drivers.camera.config.OutputType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='YUYV', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RGB', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1027,
  serialized_end=1058,
)
_sym_db.RegisterEnumDescriptor(_OUTPUTTYPE)

OutputType = enum_type_wrapper.EnumTypeWrapper(_OUTPUTTYPE)
IO_METHOD_UNKNOWN = 0
IO_METHOD_READ = 1
IO_METHOD_MMAP = 2
IO_METHOD_USERPTR = 3
YUYV = 0
RGB = 1



_CONFIG_COMPRESSCONFIG = _descriptor.Descriptor(
  name='CompressConfig',
  full_name='apollo.drivers.camera.config.Config.CompressConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_channel', full_name='apollo.drivers.camera.config.Config.CompressConfig.output_channel', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_pool_size', full_name='apollo.drivers.camera.config.Config.CompressConfig.image_pool_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=20,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=858,
  serialized_end=927,
)

_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='apollo.drivers.camera.config.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='camera_dev', full_name='apollo.drivers.camera.config.Config.camera_dev', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='apollo.drivers.camera.config.Config.frame_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pixel_format', full_name='apollo.drivers.camera.config.Config.pixel_format', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"yuyv".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='io_method', full_name='apollo.drivers.camera.config.Config.io_method', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='apollo.drivers.camera.config.Config.width', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='apollo.drivers.camera.config.Config.height', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_rate', full_name='apollo.drivers.camera.config.Config.frame_rate', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monochrome', full_name='apollo.drivers.camera.config.Config.monochrome', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brightness', full_name='apollo.drivers.camera.config.Config.brightness', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contrast', full_name='apollo.drivers.camera.config.Config.contrast', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='saturation', full_name='apollo.drivers.camera.config.Config.saturation', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sharpness', full_name='apollo.drivers.camera.config.Config.sharpness', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gain', full_name='apollo.drivers.camera.config.Config.gain', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_focus', full_name='apollo.drivers.camera.config.Config.auto_focus', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='focus', full_name='apollo.drivers.camera.config.Config.focus', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_exposure', full_name='apollo.drivers.camera.config.Config.auto_exposure', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exposure', full_name='apollo.drivers.camera.config.Config.exposure', index=16,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=100,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_white_balance', full_name='apollo.drivers.camera.config.Config.auto_white_balance', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='white_balance', full_name='apollo.drivers.camera.config.Config.white_balance', index=18,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=4000,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_per_pixel', full_name='apollo.drivers.camera.config.Config.bytes_per_pixel', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger_internal', full_name='apollo.drivers.camera.config.Config.trigger_internal', index=20,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger_fps', full_name='apollo.drivers.camera.config.Config.trigger_fps', index=21,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=30,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_name', full_name='apollo.drivers.camera.config.Config.channel_name', index=22,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_wait_ms', full_name='apollo.drivers.camera.config.Config.device_wait_ms', index=23,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2000,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spin_rate', full_name='apollo.drivers.camera.config.Config.spin_rate', index=24,
      number=25, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=200,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_type', full_name='apollo.drivers.camera.config.Config.output_type', index=25,
      number=26, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compress_conf', full_name='apollo.drivers.camera.config.Config.compress_conf', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CONFIG_COMPRESSCONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=927,
)

_CONFIG_COMPRESSCONFIG.containing_type = _CONFIG
_CONFIG.fields_by_name['io_method'].enum_type = _IOMETHOD
_CONFIG.fields_by_name['output_type'].enum_type = _OUTPUTTYPE
_CONFIG.fields_by_name['compress_conf'].message_type = _CONFIG_COMPRESSCONFIG
DESCRIPTOR.message_types_by_name['Config'] = _CONFIG
DESCRIPTOR.enum_types_by_name['IOMethod'] = _IOMETHOD
DESCRIPTOR.enum_types_by_name['OutputType'] = _OUTPUTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {

  'CompressConfig' : _reflection.GeneratedProtocolMessageType('CompressConfig', (_message.Message,), {
    'DESCRIPTOR' : _CONFIG_COMPRESSCONFIG,
    '__module__' : 'modules.drivers.camera.proto.config_pb2'
    # @@protoc_insertion_point(class_scope:apollo.drivers.camera.config.Config.CompressConfig)
    })
  ,
  'DESCRIPTOR' : _CONFIG,
  '__module__' : 'modules.drivers.camera.proto.config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.camera.config.Config)
  })
_sym_db.RegisterMessage(Config)
_sym_db.RegisterMessage(Config.CompressConfig)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/spiral_curve_config.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/spiral_curve_config.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_pb=_b('\n0modules/planning/proto/spiral_curve_config.proto\x12\x0f\x61pollo.planning\"s\n\x11SpiralCurveConfig\x12\x17\n\x0csimpson_size\x18\x01 \x01(\x05:\x01\x39\x12 \n\x12newton_raphson_tol\x18\x02 \x01(\x01:\x04\x30.01\x12#\n\x17newton_raphson_max_iter\x18\x03 \x01(\x05:\x02\x32\x30')
)




_SPIRALCURVECONFIG = _descriptor.Descriptor(
  name='SpiralCurveConfig',
  full_name='apollo.planning.SpiralCurveConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='simpson_size', full_name='apollo.planning.SpiralCurveConfig.simpson_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=9,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='newton_raphson_tol', full_name='apollo.planning.SpiralCurveConfig.newton_raphson_tol', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.01),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='newton_raphson_max_iter', full_name='apollo.planning.SpiralCurveConfig.newton_raphson_max_iter', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=20,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=184,
)

DESCRIPTOR.message_types_by_name['SpiralCurveConfig'] = _SPIRALCURVECONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SpiralCurveConfig = _reflection.GeneratedProtocolMessageType('SpiralCurveConfig', (_message.Message,), dict(
  DESCRIPTOR = _SPIRALCURVECONFIG,
  __module__ = 'modules.planning.proto.spiral_curve_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.SpiralCurveConfig)
  ))
_sym_db.RegisterMessage(SpiralCurveConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/map/tools/map_datachecker/proto/collection_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.map.tools.map_datachecker.proto import collection_check_message_pb2 as modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/map/tools/map_datachecker/proto/collection_service.proto',
  package='apollo.hdmap',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n@modules/map/tools/map_datachecker/proto/collection_service.proto\x12\x0c\x61pollo.hdmap\x1a\x46modules/map/tools/map_datachecker/proto/collection_check_message.proto2\xf1\x03\n\x18\x43ollectionCheckerService\x12^\n\x13ServiceDynamicAlign\x12!.apollo.hdmap.DynamicAlignRequest\x1a\".apollo.hdmap.DynamicAlignResponse\"\x00\x12[\n\x12ServiceStaticAlign\x12 .apollo.hdmap.StaticAlignRequest\x1a!.apollo.hdmap.StaticAlignResponse\"\x00\x12X\n\x11ServiceEightRoute\x12\x1f.apollo.hdmap.EightRouteRequest\x1a .apollo.hdmap.EightRouteResponse\"\x00\x12\x61\n\x14ServiceChannelVerify\x12\".apollo.hdmap.ChannelVerifyRequest\x1a#.apollo.hdmap.ChannelVerifyResponse\"\x00\x12[\n\x12ServiceLoopsVerify\x12 .apollo.hdmap.LoopsVerifyRequest\x1a!.apollo.hdmap.LoopsVerifyResponse\"\x00'
  ,
  dependencies=[modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_COLLECTIONCHECKERSERVICE = _descriptor.ServiceDescriptor(
  name='CollectionCheckerService',
  full_name='apollo.hdmap.CollectionCheckerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=155,
  serialized_end=652,
  methods=[
  _descriptor.MethodDescriptor(
    name='ServiceDynamicAlign',
    full_name='apollo.hdmap.CollectionCheckerService.ServiceDynamicAlign',
    index=0,
    containing_service=None,
    input_type=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2._DYNAMICALIGNREQUEST,
    output_type=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2._DYNAMICALIGNRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ServiceStaticAlign',
    full_name='apollo.hdmap.CollectionCheckerService.ServiceStaticAlign',
    index=1,
    containing_service=None,
    input_type=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2._STATICALIGNREQUEST,
    output_type=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2._STATICALIGNRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ServiceEightRoute',
    full_name='apollo.hdmap.CollectionCheckerService.ServiceEightRoute',
    index=2,
    containing_service=None,
    input_type=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2._EIGHTROUTEREQUEST,
    output_type=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2._EIGHTROUTERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ServiceChannelVerify',
    full_name='apollo.hdmap.CollectionCheckerService.ServiceChannelVerify',
    index=3,
    containing_service=None,
    input_type=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2._CHANNELVERIFYREQUEST,
    output_type=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2._CHANNELVERIFYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ServiceLoopsVerify',
    full_name='apollo.hdmap.CollectionCheckerService.ServiceLoopsVerify',
    index=4,
    containing_service=None,
    input_type=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2._LOOPSVERIFYREQUEST,
    output_type=modules_dot_map_dot_tools_dot_map__datachecker_dot_proto_dot_collection__check__message__pb2._LOOPSVERIFYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_COLLECTIONCHECKERSERVICE)

DESCRIPTOR.services_by_name['CollectionCheckerService'] = _COLLECTIONCHECKERSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/lidar/app/proto/lidar_obstacle_segmentation_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/lidar/app/proto/lidar_obstacle_segmentation_config.proto',
  package='apollo.perception.lidar',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nKmodules/perception/lidar/app/proto/lidar_obstacle_segmentation_config.proto\x12\x17\x61pollo.perception.lidar\"\x8c\x01\n\x1fLidarObstacleSegmentationConfig\x12$\n\tsegmentor\x18\x01 \x01(\t:\x11\x44ummySegmentation\x12\x1d\n\x0fuse_map_manager\x18\x02 \x01(\x08:\x04true\x12$\n\x16use_object_filter_bank\x18\x03 \x01(\x08:\x04true'
)




_LIDAROBSTACLESEGMENTATIONCONFIG = _descriptor.Descriptor(
  name='LidarObstacleSegmentationConfig',
  full_name='apollo.perception.lidar.LidarObstacleSegmentationConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='segmentor', full_name='apollo.perception.lidar.LidarObstacleSegmentationConfig.segmentor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"DummySegmentation".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_map_manager', full_name='apollo.perception.lidar.LidarObstacleSegmentationConfig.use_map_manager', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_object_filter_bank', full_name='apollo.perception.lidar.LidarObstacleSegmentationConfig.use_object_filter_bank', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=245,
)

DESCRIPTOR.message_types_by_name['LidarObstacleSegmentationConfig'] = _LIDAROBSTACLESEGMENTATIONCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LidarObstacleSegmentationConfig = _reflection.GeneratedProtocolMessageType('LidarObstacleSegmentationConfig', (_message.Message,), {
  'DESCRIPTOR' : _LIDAROBSTACLESEGMENTATIONCONFIG,
  '__module__' : 'modules.perception.lidar.app.proto.lidar_obstacle_segmentation_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.lidar.LidarObstacleSegmentationConfig)
  })
_sym_db.RegisterMessage(LidarObstacleSegmentationConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/map/tools/map_datachecker/proto/collection_error_code.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/map/tools/map_datachecker/proto/collection_error_code.proto',
  package='apollo.hdmap',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nCmodules/map/tools/map_datachecker/proto/collection_error_code.proto\x12\x0c\x61pollo.hdmap*\xab\x05\n\tErrorCode\x12\x0b\n\x07SUCCESS\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x11\n\rERROR_REQUEST\x10\x02\x12\x1d\n\x19\x45RROR_SERVICE_NO_RESPONSE\x10\x03\x12\x18\n\x14\x45RROR_REPEATED_START\x10\x04\x12\x1c\n\x18\x45RROR_CHECK_BEFORE_START\x10\x05\x12\x15\n\x11\x45RROR_GPSBIN_LACK\x10\x65\x12\x18\n\x14\x45RROR_DISKINFO_ERROR\x10\x66\x12\x16\n\x12\x45RROR_DISK_UNMOUNT\x10g\x12\x14\n\x10\x45RROR_SPEED_LACK\x10i\x12\x19\n\x15WARNING_ODOMETER_LACK\x10j\x12\x19\n\x15\x45RROR_RTKSTATUS_EMPTY\x10k\x12\x1e\n\x19\x45RROR_MAPGRPC_NOT_CONNECT\x10\xc9\x01\x12\x19\n\x14WARNING_NOT_STRAIGHT\x10\xd4\x01\x12\x1e\n\x19WARNING_PROGRESS_ROLLBACK\x10\xd5\x01\x12\x1a\n\x15\x45RROR_NOT_EIGHT_ROUTE\x10\xdd\x01\x12$\n\x1f\x45RROR_CHANNEL_VERIFY_TOPIC_LACK\x10\xe7\x01\x12(\n#ERROR_CHANNEL_VERIFY_RATES_ABNORMAL\x10\xe8\x01\x12\x1e\n\x19\x45RROR_VERIFY_NO_RECORDERS\x10\xe9\x01\x12\x1c\n\x17\x45RROR_LOOPS_NOT_REACHED\x10\xea\x01\x12\x1c\n\x17\x45RROR_VERIFY_NO_GNSSPOS\x10\xeb\x01\x12\x15\n\x10\x45RROR_NOT_STATIC\x10\xf1\x01\x12\x1b\n\x16\x45RROR_GNSS_SIGNAL_FAIL\x10\xf2\x01\x12\x17\n\x12SUCCESS_TASK_EMPTY\x10\xad\x02\x12\x17\n\x12SUCCESS_TASK_STOCK\x10\xae\x02'
)

_ERRORCODE = _descriptor.EnumDescriptor(
  name='ErrorCode',
  full_name='apollo.hdmap.ErrorCode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_SERVICE_NO_RESPONSE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_REPEATED_START', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_CHECK_BEFORE_START', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_GPSBIN_LACK', index=6, number=101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_DISKINFO_ERROR', index=7, number=102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_DISK_UNMOUNT', index=8, number=103,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_SPEED_LACK', index=9, number=105,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_ODOMETER_LACK', index=10, number=106,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_RTKSTATUS_EMPTY', index=11, number=107,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_MAPGRPC_NOT_CONNECT', index=12, number=201,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_NOT_STRAIGHT', index=13, number=212,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING_PROGRESS_ROLLBACK', index=14, number=213,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NOT_EIGHT_ROUTE', index=15, number=221,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_CHANNEL_VERIFY_TOPIC_LACK', index=16, number=231,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_CHANNEL_VERIFY_RATES_ABNORMAL', index=17, number=232,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_VERIFY_NO_RECORDERS', index=18, number=233,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_LOOPS_NOT_REACHED', index=19, number=234,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_VERIFY_NO_GNSSPOS', index=20, number=235,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NOT_STATIC', index=21, number=241,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_GNSS_SIGNAL_FAIL', index=22, number=242,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS_TASK_EMPTY', index=23, number=301,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS_TASK_STOCK', index=24, number=302,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=86,
  serialized_end=769,
)
_sym_db.RegisterEnumDescriptor(_ERRORCODE)

ErrorCode = enum_type_wrapper.EnumTypeWrapper(_ERRORCODE)
SUCCESS = 0
ERROR = 1
ERROR_REQUEST = 2
ERROR_SERVICE_NO_RESPONSE = 3
ERROR_REPEATED_START = 4
ERROR_CHECK_BEFORE_START = 5
ERROR_GPSBIN_LACK = 101
ERROR_DISKINFO_ERROR = 102
ERROR_DISK_UNMOUNT = 103
ERROR_SPEED_LACK = 105
WARNING_ODOMETER_LACK = 106
ERROR_RTKSTATUS_EMPTY = 107
ERROR_MAPGRPC_NOT_CONNECT = 201
WARNING_NOT_STRAIGHT = 212
WARNING_PROGRESS_ROLLBACK = 213
ERROR_NOT_EIGHT_ROUTE = 221
ERROR_CHANNEL_VERIFY_TOPIC_LACK = 231
ERROR_CHANNEL_VERIFY_RATES_ABNORMAL = 232
ERROR_VERIFY_NO_RECORDERS = 233
ERROR_LOOPS_NOT_REACHED = 234
ERROR_VERIFY_NO_GNSSPOS = 235
ERROR_NOT_STATIC = 241
ERROR_GNSS_SIGNAL_FAIL = 242
SUCCESS_TASK_EMPTY = 301
SUCCESS_TASK_STOCK = 302


DESCRIPTOR.enum_types_by_name['ErrorCode'] = _ERRORCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


# @@protoc_insertion_point(module_scope)
